@@ -2,14 +2,16 @@
 "_PACKAGE"
 
 ## usethis namespace: start
-#' @import rlang
 #' @import R6
+#' @import rlang
 #' @importFrom glue glue
+#' @importFrom lifecycle deprecated
 ## usethis namespace: end
 NULL
 
 the <- new_environment()
 the$throttle <- list()
+the$cache_throttle <- list()
 the$token_cache <- new_environment()
 the$last_response <- NULL
 the$last_request <- NULL
